aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/lock/db.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/includes/lock/db.php')
-rw-r--r--phpBB/includes/lock/db.php10
1 files changed, 5 insertions, 5 deletions
diff --git a/phpBB/includes/lock/db.php b/phpBB/includes/lock/db.php
index 092f4f9789..f5f1b4c6f9 100644
--- a/phpBB/includes/lock/db.php
+++ b/phpBB/includes/lock/db.php
@@ -80,11 +80,11 @@ class phpbb_lock_db
* @return bool true if lock was acquired
* false otherwise
*/
- public function lock()
+ public function acquire()
{
if ($this->locked)
{
- return true;
+ return false;
}
if (!isset($this->config[$this->config_name]))
@@ -119,15 +119,15 @@ class phpbb_lock_db
/**
* Releases the lock.
*
* The lock must have been previously obtained, that is, lock() call
* was issued and returned true.
*
* Note: Attempting to release a lock that is already released,
* that is, calling unlock() multiple times, is harmless.
*
* @return void
*/
- public function unlock()
+ public function release()
{
if ($this->locked)
{
@@ -119,15 +119,15 @@ class phpbb_lock_db
* Releases the lock.
*
- * The lock must have been previously obtained, that is, lock() call
+ * The lock must have been previously obtained, that is, acquire() call
* was issued and returned true.
*
@@ -119,15 +119,15 @@ class phpbb_lock_db
*
* Note: Attempting to release a lock that is already released,
- * that is, calling unlock() multiple times, is harmless.
+ * that is, calling release() multiple times, is harmless.
*
* @return void